CVS commit: src/sys/external/bsd/drm/dist/shared-core

2014-09-05 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Fri Sep  5 09:40:44 UTC 2014

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: i915_drv.h i915_suspend.c

Log Message:
Rename enum pipe to enum pipe so it won't conflcit with struct pipe.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 src/sys/external/bsd/drm/dist/shared-core/i915_drv.h
cvs rdiff -u -r1.6 -r1.7 \
src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/i915_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.5 src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.6
--- src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.5	Mon Jun 11 16:51:04 2012
+++ src/sys/external/bsd/drm/dist/shared-core/i915_drv.h	Fri Sep  5 09:40:44 2014
@@ -41,7 +41,7 @@
 #define DRIVER_DESC		Intel Graphics
 #define DRIVER_DATE		20080730
 
-enum pipe {
+enum pipex {
 	PIPE_A = 0,
 	PIPE_B,
 };

Index: src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.6 src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.7
--- src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.6	Tue Dec 11 07:31:39 2012
+++ src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c	Fri Sep  5 09:40:44 2014
@@ -32,7 +32,7 @@
 #include i915_drm.h
 #include i915_drv.h
 
-static bool i915_pipe_enabled(struct drm_device *dev, enum pipe pipe)
+static bool i915_pipe_enabled(struct drm_device *dev, enum pipex pipe)
 {
 	struct drm_i915_private *dev_priv = dev-dev_private;
 
@@ -42,7 +42,7 @@ static bool i915_pipe_enabled(struct drm
 		return (I915_READ(DPLL_B)  DPLL_VCO_ENABLE);
 }
 
-static void i915_save_palette(struct drm_device *dev, enum pipe pipe)
+static void i915_save_palette(struct drm_device *dev, enum pipex pipe)
 {
 	struct drm_i915_private *dev_priv = dev-dev_private;
 	unsigned long reg = (pipe == PIPE_A ? PALETTE_A : PALETTE_B);
@@ -61,7 +61,7 @@ static void i915_save_palette(struct drm
 		array[i] = I915_READ(reg + (i  2));
 }
 
-static void i915_restore_palette(struct drm_device *dev, enum pipe pipe)
+static void i915_restore_palette(struct drm_device *dev, enum pipex pipe)
 {
 	struct drm_i915_private *dev_priv = dev-dev_private;
 	unsigned long reg = (pipe == PIPE_A ? PALETTE_A : PALETTE_B);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2013-10-17 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Oct 17 21:14:05 UTC 2013

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: savage_bci.c

Log Message:
annotate some unused variables the authors want to keep


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 \
src/sys/external/bsd/drm/dist/shared-core/savage_bci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/savage_bci.c
diff -u src/sys/external/bsd/drm/dist/shared-core/savage_bci.c:1.5 src/sys/external/bsd/drm/dist/shared-core/savage_bci.c:1.6
--- src/sys/external/bsd/drm/dist/shared-core/savage_bci.c:1.5	Tue Sep  1 21:36:41 2009
+++ src/sys/external/bsd/drm/dist/shared-core/savage_bci.c	Thu Oct 17 17:14:05 2013
@@ -631,6 +631,8 @@ int savage_driver_firstopen(struct drm_d
 		aperture_base = drm_get_resource_start(dev, 2);
 		/* Automatic MTRR setup will do the right thing. */
 	}
+	__USE(fb_rsrc);
+	__USE(aper_rsrc);
 
 	ret = drm_addmap(dev, mmio_base, SAVAGE_MMIO_SIZE, _DRM_REGISTERS,
 			 _DRM_READ_ONLY, dev_priv-mmio);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2013-10-17 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Oct 17 21:15:00 UTC 2013

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: mach64_drv.h mach64_state.c

Log Message:
define a new macro that does not declare variables used in output.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 \
src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h
cvs rdiff -u -r1.1.1.1 -r1.2 \
src/sys/external/bsd/drm/dist/shared-core/mach64_state.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h:1.5 src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h:1.6
--- src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h:1.5	Thu Feb 24 02:59:44 2011
+++ src/sys/external/bsd/drm/dist/shared-core/mach64_drv.h	Thu Oct 17 17:15:00 2013
@@ -697,9 +697,12 @@ mach64_update_ring_snapshot(drm_mach64_p
  * queuing the buffer in the ring. 
  */
 
-#define DMALOCALS\
+#define DMALOCALS_NOOUT\
 	drm_mach64_freelist_t *_entry = NULL;	\
-	struct drm_buf *_buf = NULL;		\
+	struct drm_buf *_buf = NULL
+
+#define	DMALOCALS\
+	DMALOCALS_NOOUT;			\
 	u32 *_buf_wptr; int _outcount
 
 #define GETBUFPTR( __buf )		\
@@ -735,8 +738,12 @@ static __inline__ int mach64_find_pendin
 	return 0;
 }
 
+#define DMASETPTR_NOOUT( _p )			\
+	_buf = (_p)
+
 #define DMASETPTR( _p )\
 do {		\
+	DMASETPTR_NOOUT( _p );			\
 	_buf = (_p);\
 	_outcount = 0;\
 	_buf_wptr = GETBUFPTR( _buf );		\

Index: src/sys/external/bsd/drm/dist/shared-core/mach64_state.c
diff -u src/sys/external/bsd/drm/dist/shared-core/mach64_state.c:1.1.1.1 src/sys/external/bsd/drm/dist/shared-core/mach64_state.c:1.2
--- src/sys/external/bsd/drm/dist/shared-core/mach64_state.c:1.1.1.1	Sat Jul 19 01:30:41 2008
+++ src/sys/external/bsd/drm/dist/shared-core/mach64_state.c	Thu Oct 17 17:15:00 2013
@@ -560,7 +560,7 @@ static int mach64_dma_dispatch_vertex(st
 	int i = 0;
 	int done = 0;
 	int verify_ret = 0;
-	DMALOCALS;
+	DMALOCALS_NOOUT;
 
 	DRM_DEBUG(buf=%p used=%lu nbox=%d\n,
 		  buf, used, sarea_priv-nbox);
@@ -587,7 +587,7 @@ static int mach64_dma_dispatch_vertex(st
 
 	copy_buf-used = used;
 
-	DMASETPTR(copy_buf);
+	DMASETPTR_NOOUT(copy_buf);
 
 	if (sarea_priv-dirty  ~MACH64_UPLOAD_CLIPRECTS) {
 		ret = mach64_emit_state(file_priv, dev_priv);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2013-09-14 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Sat Sep 14 12:39:28 UTC 2013

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: mach64_dma.c

Log Message:
Mark mach64_set_dma_eol as unused.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 \
src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c
diff -u src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c:1.4 src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c:1.5
--- src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c:1.4	Sat Sep 12 17:16:41 2009
+++ src/sys/external/bsd/drm/dist/shared-core/mach64_dma.c	Sat Sep 14 12:39:28 2013
@@ -563,7 +563,7 @@ void mach64_dump_ring_info(drm_mach64_pr
  *
  * \sa mach64_clear_dma_eol
  */ 
-static __inline__ void mach64_set_dma_eol(volatile u32 *addr)
+static __inline__ __unused void mach64_set_dma_eol(volatile u32 *addr)
 {
 #if defined(__i386__)
 	int nr = 31;



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2012-12-10 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Tue Dec 11 07:31:40 UTC 2012

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: i915_suspend.c

Log Message:
Fix wrong reference to dev_priv-saveSWF1. It was clearly wrong.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.6 \
src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.5 src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.6
--- src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c:1.5	Sat Jun 20 01:07:10 2009
+++ src/sys/external/bsd/drm/dist/shared-core/i915_suspend.c	Tue Dec 11 07:31:39 2012
@@ -512,7 +512,7 @@ int i915_restore_state(struct drm_device
 
 	for (i = 0; i  16; i++) {
 		I915_WRITE(SWF00 + (i  2), dev_priv-saveSWF0[i]);
-		I915_WRITE(SWF10 + (i  2), dev_priv-saveSWF1[i+7]);
+		I915_WRITE(SWF10 + (i  2), dev_priv-saveSWF1[i]);
 	}
 	for (i = 0; i  3; i++)
 		I915_WRITE(SWF30 + (i  2), dev_priv-saveSWF2[i]);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-05-30 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Mon May 30 13:50:36 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_cp.c

Log Message:
Remove invalid const, the content is later passed to free.


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 \
src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.12 src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.13
--- src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.12	Wed Mar 30 19:59:04 2011
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c	Mon May 30 13:50:36 2011
@@ -378,7 +378,7 @@
 static void radeon_cp_load_microcode(drm_radeon_private_t * dev_priv)
 {
 	const char *chip_name;
-	const u32 (*cp)[2];
+	u32 (*cp)[2];
 	int i, error;
 	size_t cp_size;
 	DRM_DEBUG(\n);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-05-30 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Mon May 30 13:52:26 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_state.c

Log Message:
Fix format strings to match arguments


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 \
src/sys/external/bsd/drm/dist/shared-core/radeon_state.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_state.c
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_state.c:1.6 src/sys/external/bsd/drm/dist/shared-core/radeon_state.c:1.7
--- src/sys/external/bsd/drm/dist/shared-core/radeon_state.c:1.6	Sat Nov  6 22:06:10 2010
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_state.c	Mon May 30 13:52:26 2011
@@ -1748,7 +1748,7 @@
 	DRM_DEBUG(tex=%dx%d blit=%d\n, tex_width, tex-height, blit_width);
 
 	do {
-		DRM_DEBUG(tex: ofs=0x%x p=%d f=%d x=%hd y=%hd w=%hd h=%hd\n,
+		DRM_DEBUG(tex: ofs=0x%x p=%d f=%d x=%u y=%u w=%u h=%u\n,
 			  tex-offset  10, tex-pitch, tex-format,
 			  image-x, image-y, image-width, image-height);
 



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-05-25 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed May 25 14:11:37 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: mga_drv.h

Log Message:
fix printf formats.


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r1.4 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/mga_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.3 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.4
--- src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.3	Tue May 24 14:22:02 2011
+++ src/sys/external/bsd/drm/dist/shared-core/mga_drv.h	Wed May 25 10:11:36 2011
@@ -285,7 +285,7 @@
 do {	\
 	if ( MGA_VERBOSE ) {		\
 		DRM_INFO( BEGIN_DMA( %d )\n, (n) );		\
-		DRM_INFO(space=0x%x req=0x%lx\n,			\
+		DRM_INFO(space=0x%x req=0x%x\n,			\
 			  dev_priv-prim.space, (n) * DMA_BLOCK_SIZE );	\
 	}\
 	prim = dev_priv-prim.start;	\
@@ -335,7 +335,7 @@
 #define DMA_WRITE( offset, val )	\
 do {	\
 	if ( MGA_VERBOSE ) {		\
-		DRM_INFO(DMA_WRITE( 0x%08x ) at 0x%04lx\n,	\
+		DRM_INFO(DMA_WRITE( 0x%08x ) at 0x%04zx\n,	\
 			  (u32)(val), write + (offset) * sizeof(u32) );	\
 	}\
 	*(volatile u32 *)(prim + write + (offset) * sizeof(u32)) = val;	\



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-05-25 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed May 25 15:15:55 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: mga_drv.h

Log Message:
more wrong formats.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/mga_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.4 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.5
--- src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.4	Wed May 25 10:11:36 2011
+++ src/sys/external/bsd/drm/dist/shared-core/mga_drv.h	Wed May 25 11:15:55 2011
@@ -285,7 +285,7 @@
 do {	\
 	if ( MGA_VERBOSE ) {		\
 		DRM_INFO( BEGIN_DMA( %d )\n, (n) );		\
-		DRM_INFO(space=0x%x req=0x%x\n,			\
+		DRM_INFO(space=0x%x req=0x%zx\n,			\
 			  dev_priv-prim.space, (n) * DMA_BLOCK_SIZE );	\
 	}\
 	prim = dev_priv-prim.start;	\



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-05-24 Thread Joerg Sonnenberger
Module Name:src
Committed By:   joerg
Date:   Tue May 24 18:22:02 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: mga_drv.h

Log Message:
Use some format specifiers that actually exist


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/mga_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.2 src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.3
--- src/sys/external/bsd/drm/dist/shared-core/mga_drv.h:1.2	Thu Feb 24 07:59:44 2011
+++ src/sys/external/bsd/drm/dist/shared-core/mga_drv.h	Tue May 24 18:22:02 2011
@@ -285,7 +285,7 @@
 do {	\
 	if ( MGA_VERBOSE ) {		\
 		DRM_INFO( BEGIN_DMA( %d )\n, (n) );		\
-		DRM_INFO(space=0x%x req=0x%Zx\n,			\
+		DRM_INFO(space=0x%x req=0x%lx\n,			\
 			  dev_priv-prim.space, (n) * DMA_BLOCK_SIZE );	\
 	}\
 	prim = dev_priv-prim.start;	\
@@ -335,7 +335,7 @@
 #define DMA_WRITE( offset, val )	\
 do {	\
 	if ( MGA_VERBOSE ) {		\
-		DRM_INFO(DMA_WRITE( 0x%08x ) at 0x%04Zx\n,	\
+		DRM_INFO(DMA_WRITE( 0x%08x ) at 0x%04lx\n,	\
 			  (u32)(val), write + (offset) * sizeof(u32) );	\
 	}\
 	*(volatile u32 *)(prim + write + (offset) * sizeof(u32)) = val;	\



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-03-30 Thread Michael van Elst
Module Name:src
Committed By:   mlelstv
Date:   Wed Mar 30 17:21:05 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_cp.c

Log Message:
Add missing agp.h include file.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 \
src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.10 src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.11
--- src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.10	Sun Mar 27 08:45:11 2011
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c	Wed Mar 30 17:21:04 2011
@@ -35,6 +35,10 @@
 #include radeon_drv.h
 #include r300_reg.h
 
+#if defined(__NetBSD__)
+#include agp.h
+#endif
+
 #define RADEON_FIFO_DEBUG	0
 
 static int radeon_do_cleanup_cp(struct drm_device * dev);



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-03-30 Thread Matthias Scheler
Module Name:src
Committed By:   tron
Date:   Wed Mar 30 19:59:04 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_cp.c

Log Message:
Fix build of radeondrm kernel module.


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 \
src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.11 src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.12
--- src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.11	Wed Mar 30 17:21:04 2011
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c	Wed Mar 30 19:59:04 2011
@@ -35,7 +35,7 @@
 #include radeon_drv.h
 #include r300_reg.h
 
-#if defined(__NetBSD__)
+#if defined(__NetBSD__)  defined(_KERNEL_OPT)
 #include agp.h
 #endif
 



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-02-24 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Feb 24 08:02:55 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: i915_drm.h i915_drv.h
i915_irq.c

Log Message:
change int pipe into unsigned int pipe.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.2 -r1.2 \
src/sys/external/bsd/drm/dist/shared-core/i915_drm.h
cvs rdiff -u -r1.3 -r1.4 src/sys/external/bsd/drm/dist/shared-core/i915_drv.h
cvs rdiff -u -r1.4 -r1.5 src/sys/external/bsd/drm/dist/shared-core/i915_irq.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/i915_drm.h
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_drm.h:1.1.1.2 src/sys/external/bsd/drm/dist/shared-core/i915_drm.h:1.2
--- src/sys/external/bsd/drm/dist/shared-core/i915_drm.h:1.1.1.2	Fri Jun 19 03:22:24 2009
+++ src/sys/external/bsd/drm/dist/shared-core/i915_drm.h	Thu Feb 24 08:02:55 2011
@@ -254,6 +254,7 @@
 	 * out there check for HAVE_I915_FLIP and so might pick up this
 	 * version.
 	 */
+	/* XXXMRG: make this unsigned? */
 	int pipes;
 } drm_i915_flip_t;
 

Index: src/sys/external/bsd/drm/dist/shared-core/i915_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.3 src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.4
--- src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.3	Thu Feb 24 07:59:44 2011
+++ src/sys/external/bsd/drm/dist/shared-core/i915_drv.h	Thu Feb 24 08:02:55 2011
@@ -440,10 +440,10 @@
 			struct drm_file *file_priv);
 
 void
-i915_enable_pipestat(drm_i915_private_t *dev_priv, int pipe, u32 mask);
+i915_enable_pipestat(drm_i915_private_t *dev_priv, unsigned int pipe, u32 mask);
 
 void
-i915_disable_pipestat(drm_i915_private_t *dev_priv, int pipe, u32 mask);
+i915_disable_pipestat(drm_i915_private_t *dev_priv, unsigned int pipe, u32 mask);
 
 
 /* i915_mem.c */

Index: src/sys/external/bsd/drm/dist/shared-core/i915_irq.c
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_irq.c:1.4 src/sys/external/bsd/drm/dist/shared-core/i915_irq.c:1.5
--- src/sys/external/bsd/drm/dist/shared-core/i915_irq.c:1.4	Thu Feb 24 07:59:44 2011
+++ src/sys/external/bsd/drm/dist/shared-core/i915_irq.c	Thu Feb 24 08:02:55 2011
@@ -75,7 +75,7 @@
 }
 
 static inline u32
-i915_pipestat(int pipe)
+i915_pipestat(unsigned int pipe)
 {
 	if (pipe == 0)
 	return PIPEASTAT;
@@ -85,7 +85,7 @@
 }
 
 void
-i915_enable_pipestat(drm_i915_private_t *dev_priv, int pipe, u32 mask)
+i915_enable_pipestat(drm_i915_private_t *dev_priv, unsigned int pipe, u32 mask)
 {
 	if ((dev_priv-pipestat[pipe]  mask) != mask) {
 		u32 reg = i915_pipestat(pipe);
@@ -98,7 +98,7 @@
 }
 
 void
-i915_disable_pipestat(drm_i915_private_t *dev_priv, int pipe, u32 mask)
+i915_disable_pipestat(drm_i915_private_t *dev_priv, unsigned int pipe, u32 mask)
 {
 	if ((dev_priv-pipestat[pipe]  mask) != 0) {
 		u32 reg = i915_pipestat(pipe);
@@ -119,7 +119,7 @@
  * before reading such registers if unsure.
  */
 static int
-i915_pipe_enabled(struct drm_device *dev, int pipe)
+i915_pipe_enabled(struct drm_device *dev, unsigned int pipe)
 {
 	drm_i915_private_t *dev_priv = (drm_i915_private_t *) dev-dev_private;
 	unsigned long pipeconf = pipe ? PIPEBCONF : PIPEACONF;



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-02-17 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Fri Feb 18 02:52:42 UTC 2011

Removed Files:
src/sys/external/bsd/drm/dist/shared-core: via_drv.c

Log Message:
get rid of this stale copy of via_drv.c, the one we want is in bsd-core


To generate a diff of this commit:
cvs rdiff -u -r1.3 -r0 src/sys/external/bsd/drm/dist/shared-core/via_drv.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2011-01-21 Thread David Young
Module Name:src
Committed By:   dyoung
Date:   Fri Jan 21 21:57:17 UTC 2011

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: i915_drv.h

Log Message:
unifdef -U__linux__ -U__FreeBSD__.  No functional change intended.


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.4 -r1.2 \
src/sys/external/bsd/drm/dist/shared-core/i915_drv.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/i915_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.1.1.4 src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.2
--- src/sys/external/bsd/drm/dist/shared-core/i915_drv.h:1.1.1.4	Fri Jun 19 03:22:24 2009
+++ src/sys/external/bsd/drm/dist/shared-core/i915_drv.h	Fri Jan 21 21:57:16 2011
@@ -232,9 +232,6 @@
 	u8 saveDACDATA[256*3]; /* 256 3-byte colors */
 	u8 saveCR[37];
 	struct {
-#ifdef __linux__
-		struct drm_mm gtt_space;
-#endif
 		/**
 		 * List of objects currently involved in rendering from the
 		 * ringbuffer.
@@ -267,16 +264,6 @@
 		 * outstanding.
 		 */
 		struct list_head request_list;
-#ifdef __linux__
-		/**
-		 * We leave the user IRQ off as much as possible,
-		 * but this means that requests will finish and never
-		 * be retired once the system goes idle. Set a timer to
-		 * fire periodically while the ring is running. When it
-		 * fires, go retire requests.
-		 */
-		struct delayed_work retire_work;
-#endif
 		uint32_t next_gem_seqno;
 
 		/**
@@ -556,10 +543,6 @@
 		LOCK_TEST_WITH_RETURN(dev, file_priv);			\
 } while (0)
 
-#if defined(__FreeBSD__)
-typedef boolean_t bool;
-#endif
-
 #define I915_READ(reg)		DRM_READ32(dev_priv-mmio_map, (reg))
 #define I915_WRITE(reg,val)	DRM_WRITE32(dev_priv-mmio_map, (reg), (val))
 #define I915_READ16(reg)	DRM_READ16(dev_priv-mmio_map, (reg))



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2010-08-21 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Sat Aug 21 11:54:37 UTC 2010

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: via_drv.c

Log Message:
Get viadrm working again


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sys/external/bsd/drm/dist/shared-core/via_drv.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h:1.7 src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h:1.8
--- src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h:1.7	Mon May 24 01:39:06 2010
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h	Sat Jun 26 22:59:31 2010
@@ -150,6 +150,11 @@
 	CHIP_RV730,
 	CHIP_RV710,
 	CHIP_RV740,
+	CHIP_CEDAR,
+	CHIP_REDWOOD,
+	CHIP_JUNIPER,
+	CHIP_CYPRESS,
+	CHIP_HEMLOCK,
 	CHIP_LAST,
 };
 



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2009-03-29 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Mon Mar 30 01:38:21 UTC 2009

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_cp.c

Log Message:
apply from sys/dev:
revision 1.12
date: 2009/03/29 19:37:25;  author: mrg;  state: Exp;  lines: +9 -3
XXX:  for now, add the DRM_NETBSD_HANDLE2ADDR() hack in a few places.
update a debug message.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 \
src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c
diff -u src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.2 src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.3
--- src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c:1.2	Sun Jul 20 02:58:40 2008
+++ src/sys/external/bsd/drm/dist/shared-core/radeon_cp.c	Mon Mar 30 01:38:21 2009
@@ -963,6 +963,13 @@
 	 RADEON_ROUND_PREC_8TH_PIX);
 
 
+#ifdef __NetBSD__	/* XXX */
+
+	init-ring_offset = DRM_NETBSD_HANDLE2ADDR(init-ring_offset);
+	init-ring_rptr_offset = DRM_NETBSD_HANDLE2ADDR(init-ring_rptr_offset);
+	init-buffers_offset = DRM_NETBSD_HANDLE2ADDR(init-buffers_offset);
+	init-gart_textures_offset = DRM_NETBSD_HANDLE2ADDR(init-gart_textures_offset);
+#endif
 	dev_priv-ring_offset = init-ring_offset;
 	dev_priv-ring_rptr_offset = init-ring_rptr_offset;
 	dev_priv-buffers_offset = init-buffers_offset;
@@ -977,7 +984,8 @@
 
 	dev_priv-cp_ring = drm_core_findmap(dev, init-ring_offset);
 	if (!dev_priv-cp_ring) {
-		DRM_ERROR(could not find cp ring region!\n);
+		DRM_ERROR(could not find cp ring region! offset 0x%lx\n,
+			  init-ring_offset);
 		radeon_do_cleanup_cp(dev);
 		return -EINVAL;
 	}
Index: src/sys/external/bsd/drm/dist/shared-core/via_drv.c
diff -u src/sys/external/bsd/drm/dist/shared-core/via_drv.c:1.2 src/sys/external/bsd/drm/dist/shared-core/via_drv.c:1.3
--- src/sys/external/bsd/drm/dist/shared-core/via_drv.c:1.2	Sun Sep 27 12:39:05 2009
+++ src/sys/external/bsd/drm/dist/shared-core/via_drv.c	Sat Aug 21 11:54:36 2010
@@ -1,157 +1,97 @@
-/*
- * Copyright 1998-2003 VIA Technologies, Inc. All Rights Reserved.
- * Copyright 2001-2003 S3 Graphics, Inc. All Rights Reserved.
+/* $NetBSD: via_drv.c,v 1.3 2010/08/21 11:54:36 jmcneill Exp $ */
+
+/* via_drv.c -- VIA unichrome driver -*- linux-c -*-
+ * Created: Fri Aug 12 2005 by anh...@freebsd.org
+ */
+/*-
+ * Copyright 2005 Eric Anholt
+ * Copyright 2007 Jared D. McNeill
+ * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the Software),
  * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sub license,
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
  * Software is furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice (including the
- * next paragraph) shall be included in all copies or substantial portions
- * of the Software.
+ * The above copyright notice and this permission notice (including the next
+ * paragraph) shall be included in all copies or substantial portions of the
+ * Software.
  *
  * THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
  * VIA, S3 GRAPHICS, AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
  * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
  * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
  */
 
+#include sys/cdefs.h
+__KERNEL_RCSID(0, $NetBSD: via_drv.c,v 1.3 2010/08/21 11:54:36 jmcneill Exp $);
+
 #include drmP.h
+#include drm.h
 #include via_drm.h
 #include via_drv.h
-
 #include drm_pciids.h
 
-
-static int dri_library_name(struct drm_device * dev, char * buf)
-{
-	return snprintf(buf, PAGE_SIZE, unichrome\n);
-}
-
-static struct pci_device_id pciidlist[] = {
+/* drv_PCI_IDs comes from drm_pciids.h, generated from drm_pciids.txt. */
+static drm_pci_id_list_t via_pciidlist[] = {
 	viadrv_PCI_IDS
 };
 
-
-#ifdef VIA_HAVE_FENCE
-extern struct drm_fence_driver via_fence_driver;
-#endif
-
-#ifdef VIA_HAVE_BUFFER
-
-/**
- * If there's no thrashing. This is the preferred memory type order.
- */
-static uint32_t via_mem_prios[] = {DRM_BO_MEM_PRIV0, DRM_BO_MEM_VRAM, DRM_BO_MEM_TT, DRM_BO_MEM_LOCAL};
-
-/**
- * If we have thrashing, most memory will be evicted to TT anyway, so we might as well
- * just move the new buffer into TT from the start.
- */
-static uint32_t via_busy_prios[] = {DRM_BO_MEM_TT, DRM_BO_MEM_PRIV0, DRM_BO_MEM_VRAM, DRM_BO_MEM_LOCAL};
-
-
-static struct drm_bo_driver via_bo_driver = {
-	.mem_type_prio = via_mem_prios,
-	.mem_busy_prio = via_busy_prios,
-	.num_mem_type_prio = DRM_ARRAY_SIZE(via_mem_prios),
-	.num_mem_busy_prio = DRM_ARRAY_SIZE(via_busy_prios),
-	.create_ttm_backend_entry = via_create_ttm_backend_entry,
-	.fence_type = via_fence_types,
-	.invalidate_caches = via_invalidate_caches,
-	.init_mem_type = via_init_mem_type,
-	.evict_flags = via_evict_flags,
-	.move = NULL,
-	.ttm_cache_flush = NULL,
-	.command_stream_barrier = NULL
-};
-#endif
-
-static int probe(struct pci_dev *pdev, const struct pci_device_id *ent);
-static struct drm_driver driver = {
-	.driver_features =
-	DRIVER_USE_AGP | DRIVER_USE_MTRR | DRIVER_HAVE_IRQ |
-	DRIVER_IRQ_SHARED,
-	.load = via_driver_load,
-	.unload = via_driver_unload,
-#ifndef VIA_HAVE_CORE_MM
-	.context_ctor = via_init_context,
-#endif
-	.context_dtor = 
@@ -1,157 +1,97 @@
  * THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL
- * VIA, S3 GRAPHICS, AND/OR ITS SUPPLIERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
- * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
- * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * ERIC ANHOLT BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+ * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+ *
+ * Authors:
+ *Eric Anholt anh...@freebsd.org
+ *Jared D. McNeill jmcne...@netbsd.org
+ *
  */
 

CVS commit: src/sys/external/bsd/drm/dist/shared-core

2010-07-05 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Tue Jul  6 04:15:45 UTC 2010

Removed Files:
src/sys/external/bsd/drm/dist/shared-core: r600_microcode.h
radeon_microcode.h radeonhd_microcode.h

Log Message:
kill these old built-in firmware headers; we use the ones installed into
the filesystem from src/sys/microcode/radeon now.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r0 \
src/sys/external/bsd/drm/dist/shared-core/r600_microcode.h
cvs rdiff -u -r1.1.1.1 -r0 \
src/sys/external/bsd/drm/dist/shared-core/radeon_microcode.h
cvs rdiff -u -r1.1 -r0 \
src/sys/external/bsd/drm/dist/shared-core/radeonhd_microcode.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/external/bsd/drm/dist/shared-core

2010-06-26 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Sat Jun 26 22:59:31 UTC 2010

Modified Files:
src/sys/external/bsd/drm/dist/shared-core: radeon_drv.h

Log Message:
add CHIP_CEDAR, CHIP_REDWOOD, CHIP_JUNIPER, CHIP_CYPRESS and CHIP_HEMLOCK.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 \
src/sys/external/bsd/drm/dist/shared-core/radeon_drv.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
